@@ -17,22 +17,24 @@ if ($w->unknown_registrar) {
 	die "domain found, registrar unknown. raw data follows\n" . $w->raw_whois_text . "\n";
 }
 
-print "Registrar: ", $w->registrar, "\n";
-print "Domain: ", $w->domain, "\n";
-print "Name: ", $w->name, "\n";
-print "Tag: ", $w->tag, "\n";
-print "Address:\n", map { "    $_\n" } $w->address;
-print "Country: ", $w->country, "\n";
-print "Name Servers:\n", map { "    $$_[0] ($$_[1])\n" }
+print "REGISTRARY	== ", $w->registrar, "\n\n";
+print "DOMAIN		== ", $w->domain, "\n\n";
+print "NAME		== ", $w->name, "\n\n";
+print "TAG		== ", $w->tag, "\n\n";
+print "ADDRESS		==v\n", map { "    $_\n" } $w->address;
+print "\nCOUNTRY		== ", $w->country, "\n\n";
+print "NAME SERVERS	==v\n", map { "    $$_[0] ($$_[1])\n" }
   @{$w->servers};
+print "\n";
 my ($c, $t);
 if ($c = $w->contacts) {
-  print "Contacts:\n";
+  print "CONTACTS	==v\n";
   for $t (sort keys %$c) {
-    print "    $t:\n";
+    print "    $t ==\n";
     print map { "\t$_\n" } @{$$c{$t}};
   }
+  print "\n";
 }
 
-print "Record created:", $w->record_created ;
-print "\nRecord updated:", $w->record_updated,"\n";
+print "RECORD CREATED	== ", $w->record_created,"\n\n";
+print "RECORD UPDATED	== ", $w->record_updated,"\n\n";
